"use client";
import { Star } from "lucide-react";
import Image from "next/image";
import Link from "next/link";
import React from "react";
import useSWR from "swr";
import { Skeleton } from "@/components/ui/skeleton";

const fetcher = (url) =>
  fetch(url).then((res) => {
    if (!res.ok) throw new Error("Failed to fetch stores");
    return res.json();
  });

export default function StoreList() {
  const { data, error, isLoading } = useSWR(
    `${process.env.NEXT_PUBLIC_BASE_URL}getStoreList`,
    fetcher
  );

  console.log(data?.stores);

  const stores = data?.stores?.sort(() => 0.5 - Math.random()).slice(0, 6);

  console.log(stores);

  if (error) return <div>Failed to load stores.</div>;

  return (
    <div className="grid sm:grid-cols-3 grid-cols-2  md:grid-cols-4 lg:grid-cols-6 gap-4">
      {isLoading
        ? Array.from({ length: 6 }).map((_, i) => (
            <div
              key={i}
              className="border-secondary border rounded-2xl p-3 flex flex-col items-center w-full"
            >
              <Skeleton className="w-[110px] h-[110px] rounded-full mb-2" />
              <Skeleton className="w-3/4 h-5 my-1" />
              <Skeleton className="w-1/2 h-4 mb-2" />
              <Skeleton className="w-full h-10 rounded-md" />
            </div>
          ))
        : stores?.map((store) => (
            <div
              key={store.store_id}
              className="border-secondary border rounded-2xl p-3 flex flex-col items-center w-full"
            >
              <Image
                src={
                  process.env.NEXT_PUBLIC_IMAGE_URL + "/" + store.store_image ||
                  "/assets/product-test-img/store-card.png"
                }
                alt={store.name}
                height={110}
                width={110}
                className="rounded-full object-cover h-32 w-32 "
              />
              <div className="w-full font-quicksand">
                <h3 className="font-bold text-lg text-center mt-2">
                  {store.store_name}
                </h3>
                {/* <p className="text-customGrayBlack text-sm flex justify-between">
                  <span>{store.category || "General"}</span>
                  <span className="flex items-center gap-1">
                    <Star size={15} className="text-yellow-500 fill-current" />(
                    {store.rating || "4.5"})
                  </span>
                </p> */}
                <Link
                  href={`/store/${store.store_id}`}
                  className="bg-primary text-white text-sm font-bold rounded-lg mt-2 w-full py-3 px-2 block text-center"
                >
                  View Store
                </Link>
              </div>
            </div>
          ))}
    </div>
  );
}
